@@ -4,7 +4,7 @@ use warnings;
 
 use Test2::IPC;
 
-our $VERSION = '0.000094';
+our $VERSION = '0.000096';
 
 our @CARP_NOT = qw/Test2::Util::HashBase/;
 
@@ -157,7 +157,7 @@ sub detach {
     my $self = shift;
 
     if ($self->{+PID} == $$ && $self->{+TID} == get_tid) {
-        cluck "You must detach INSIDE the child process/thread";
+        cluck "You must detach INSIDE the child process/thread ($$, " . get_tid . " instead of $self->{+PID}, $self->{+TID})";
         return;
     }
 
@@ -494,9 +494,9 @@ want the subtest to keep receiving events while other events are also being
 generated. This class implements subtests that stay open until you decide to
 close them.
 
-This is mainly useful for tools that start a subtest in one process or thread
-and then spawn children. In many cases it is nice to let the parent process
-continue instead of waiting on the children.
+This is mainly useful for tools that start a subtest in one process and then
+spawn children. In many cases it is nice to let the parent process continue
+instead of waiting on the children.
 
 =head1 SYNOPSIS
 
@@ -514,10 +514,6 @@ continue instead of waiting on the children.
         ok(1, "Event in child process");
     });
 
-    $ast->run_thread(sub {
-        ok(1, "Event in child thread");
-    });
-
     ...
 
     $ast->finish;
@@ -719,6 +715,11 @@ C<< $ast->wait >>, or C<< $ast->finish >> are called.
 
 =item my $thr = $ast->run_thread(sub { ... });
 
+B<** DISCOURAGED **> Threads cause problems. This method remains for anyone who
+REALYL wants it, but it is no longer supported. Tests for this functionality do
+not even run unless the AUTHOR_TESTING or T2_DO_THREAD_TESTS env vars are
+enabled.
+
 Same as C<< $ast->run() >>, except that the codeblock is run in a child
 thread.
 
